@@ -1,10 +1,6 @@
-# Copyright (C) 2006-2012 Dan Pascu. See LICENSE for details.
-#
 
 """UNIX process and signal management"""
 
-__all__ = ['Process', 'ProcessError', 'Signals', 'process']
-
 import sys
 import os
 import errno
@@ -15,6 +11,9 @@ from application import log
 from application.python.types import Singleton
 
 
+__all__ = ['Process', 'ProcessError', 'Signals', 'process']
+
+
 class ProcessError(Exception): pass
 
 
@@ -81,8 +80,8 @@ class Process(object):
                 except ValueError:
                     pass
                 else:
-                    ## Check if the process identified by pid is running
-                    ## Send the process a signal of zero (0)
+                    # Check if the process identified by pid is running
+                    # Send the process a signal of zero (0)
                     try:
                         os.kill(pid, 0)
                     except OSError, why:
@@ -95,40 +94,40 @@ class Process(object):
 
     def _do_fork(self):
         """Perform the Unix double fork"""
-        ## First fork.
-        ## This will return control to the command line/shell that invoked us and
-        ## will guarantee that the forked child will not be a process group leader
-        ## (which is required for setsid() below to succeed).
+        # First fork.
+        # This will return control to the command line/shell that invoked us and
+        # will guarantee that the forked child will not be a process group leader
+        # (which is required for setsid() below to succeed).
         try:
             pid = os.fork()
             if pid > 0:
-                sys.exit(0) ## exit parent
-                #os._exit(0)
+                sys.exit(0)  # exit parent
+                # os._exit(0)
         except OSError, e:
             raise ProcessError("fork #1 failed: %d: %s" % (e.errno, e.strerror))
         
-        ## Decouple from the controling terminal.
-        ## Calling setsid() we become a process group and session group leader.
-        ## Since a controlling terminal is associated with a session, and this
-        ## new session has not yet acquired a controlling terminal our process
-        ## now has no controlling terminal, which is a Good Thing for daemons.
+        # Decouple from the controlling terminal.
+        # Calling setsid() we become a process group and session group leader.
+        # Since a controlling terminal is associated with a session, and this
+        # new session has not yet acquired a controlling terminal our process
+        # now has no controlling terminal, which is a Good Thing for daemons.
         os.setsid()
         
-        ## Second fork
-        ## This will allow the parent (the session group leader obtained above)
-        ## to exit. This means that the child, as a non-session group leader,
-        ## can never regain a controlling terminal.
+        # Second fork
+        # This will allow the parent (the session group leader obtained above)
+        # to exit. This means that the child, as a non-session group leader,
+        # can never regain a controlling terminal.
         try:
             pid = os.fork()
             if pid > 0:
-                sys.exit(0) ## exit 1st child too
-                #os._exit(0)
+                sys.exit(0)  # exit 1st child too
+                # os._exit(0)
         except OSError, e:
             raise ProcessError("fork #2 failed: %d: %s" % (e.errno, e.strerror))
         
-        ## Setup our environment.
-        ## Change working directory to / so we do not keep any directory in use
-        ## preventing them from being unmounted. Also set file creation mask.
+        # Setup our environment.
+        # Change working directory to / so we do not keep any directory in use
+        # preventing them from being unmounted. Also set file creation mask.
         os.chdir("/")
         os.umask(022)
 
@@ -146,7 +145,7 @@ class Process(object):
             raise ProcessError("unable to write pidfile %s: %s" % (self._pidfile, str(e)))
 
     def _redirect_stdio(self):
-        """Redirect stdin, stdout and stderr to /dev/null"""
+        """Redirect standard input, standard output and standard error to /dev/null"""
         sys.stdout.flush()
         sys.stderr.flush()
         null = os.open('/dev/null', os.O_RDWR)
@@ -158,14 +157,14 @@ class Process(object):
     def _setup_signal_handlers(self):
         """Setup the signal handlers for daemon mode"""
         signals = self.signals
-        ## Ignore Terminal I/O Signals
+        # Ignore Terminal I/O Signals
         if hasattr(signal, 'SIGTTOU'):
             signals.ignore(signal.SIGTTOU)
         if hasattr(signal, 'SIGTTIN'):
             signals.ignore(signal.SIGTTIN)
         if hasattr(signal, 'SIGTSTP'):
             signals.ignore(signal.SIGTSTP)
-        ## Ignore USR signals
+        # Ignore USR signals
         if hasattr(signal, 'SIGUSR1'):
             signals.ignore(signal.SIGUSR1)
         if hasattr(signal, 'SIGUSR2'):
@@ -194,7 +193,7 @@ class Process(object):
 
     def get_config_directories(self):
         """Return a tuple containing the system and local config directories."""
-        return (self._system_config_directory, self._local_config_directory)
+        return self._system_config_directory, self._local_config_directory
 
     def config_file(self, name):
         """Return a config file name. Lookup order: name if absolute, local_dir/name, system_dir/name, None if none found"""
@@ -223,43 +222,36 @@ class Signals(object):
     
     def __init__(self):
         self._handlers = {}
-        if not hasattr(signal, '_original_signal'):
-            signal._original_signal = signal.signal
+        self._original_signal = signal.signal
 
     def __dispatcher(self, signum, frame):
         for handler in self._handlers.get(signum, []):
             handler(signum, frame)
 
-    def add_handler(self, signum, sighandler):
+    def add_handler(self, signum, handler):
         """Add handler to handler list for signal"""
-        if not callable(sighandler):
+        if not callable(handler):
             raise RuntimeError("signal handler needs to be a callable")
-        self._handlers.setdefault(signum, set()).add(sighandler)
+        self._handlers.setdefault(signum, set()).add(handler)
         if signal.getsignal(signum) != self.__dispatcher:
-            signal._original_signal(signum, self.__dispatcher)
+            self._original_signal(signum, self.__dispatcher)
 
     def ignore(self, signum):
         """Ignore signal"""
-        signal._original_signal(signum, signal.SIG_IGN)
-        try:
-            del self._handlers[signum]
-        except KeyError:
-            pass
+        self._original_signal(signum, signal.SIG_IGN)
+        self._handlers.pop(signum, None)
 
     def default_handler(self, signum):
         """Use default handler for signal"""
-        signal._original_signal(signum, signal.SIG_DFL)
-        try:
-            del self._handlers[signum]
-        except KeyError:
-            pass
+        self._original_signal(signum, signal.SIG_DFL)
+        self._handlers.pop(signum, None)
 
     def steal_handlers(self, enable):
         """Replace signal() from the signal module with add_handler()"""
         if enable:
             signal.signal = self.add_handler
         else:
-            signal.signal = signal._original_signal
+            signal.signal = self._original_signal
 
 
 process = Process()
