@@ -2,7 +2,8 @@
 
 from time import time
 from zope.interface import implements
-from application.notification import Any, IObserver, NotificationData, NotificationCenter, ObserverWeakrefProxy
+from application.notification import IObserver, NotificationData, NotificationCenter, ObserverWeakrefProxy
+
 
 class Sender(object):
     def publish(self):
@@ -17,6 +18,7 @@ class Sender(object):
     def __repr__(self):
         return '%s()' % self.__class__.__name__
 
+
 class AnonymousSender(Sender):
     def publish(self):
         center = NotificationCenter()
@@ -27,6 +29,7 @@ class AnonymousSender(Sender):
         print "Expecting no observer to receive notifications (CatchAllObserver and VolatileAllObserver have been unregistered)"
         center.post_notification(name='empty', data=None)
 
+
 class CatchAllObserver(object):
     """An observer that registers itself to receive all notifications."""
     implements(IObserver)
@@ -42,6 +45,7 @@ class CatchAllObserver(object):
     def handle_notification(self, notification):
         print "In CatchAllObserver got %r" % (notification,)
 
+
 class SimpleObserver(object):
     """An observer that registers itself for notifications with name 'simple'."""
     implements(IObserver)
@@ -57,6 +61,7 @@ class SimpleObserver(object):
     def handle_notification(self, notification):
         print "In SimpleObserver got %r" % (notification,)
 
+
 class ObjectObserver(object):
     """An observer that registers itself for notifications coming from a specific object."""
     implements(IObserver)
@@ -75,6 +80,7 @@ class ObjectObserver(object):
     def handle_notification(self, notification):
         print "In ObjectObserver got %r" % (notification,)
 
+
 class VolatileAllObserver(object):
     """An observer that registers itself to receive all notifications and it is weakly referenced"""
     implements(IObserver)
@@ -87,7 +93,7 @@ class VolatileAllObserver(object):
         print "In VolatileAllObserver got %r" % (notification,)
 
 
-# instatiate senders
+# instantiate senders
 sender = Sender()
 anonymous = AnonymousSender()
 
